@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 
@@ -30,7 +30,7 @@
 /*
  *
  *
- * DO NOT USE THESE CRAPPY TESTS AS EXAMPLE CODE. USE THE DOCS AND examples/*
+ * DO NOT USE THESE CRAPPY TESTS AS EXAMPLE CODE. USE THE DOCS AND examples
  *
  *
  *
@@ -45,8 +45,11 @@
 
 #include <gconf/gconf.h>
 #include <stdio.h>
+#include <string.h>
+#include <stdlib.h>
 #include <unistd.h>
 #include <math.h>
+#include <locale.h>
 #include <gconf/gconf-internals.h>
 
 /* glibc printf() functions accept NULL for a %s format, but to be
@@ -296,7 +299,7 @@ check_one_schema(GConfEngine* conf, const gchar** keyp, GConfSchema* schema)
 
       if (err != NULL)
         {
-          check (gotten == NULL, "NULL not returned though there was an error");
+          check (val == NULL, "NULL not returned though there was an error");
 
           fprintf (stderr, "Failed to get key `%s': %s\n",
                    *keyp, err->message);
@@ -782,6 +785,8 @@ main (int argc, char** argv)
 {
   GConfEngine* conf;
   GError* err = NULL;
+
+  setlocale (LC_ALL, "");
   
   if (!gconf_init(argc, argv, &err))
     {
